@@ -44,6 +44,8 @@ class ZIDS_SharedArtifacts():
                 self.load_csv(absolute_path, name)
             elif file_type == 'pickle':
                 self.load_csv(absolute_path, name)
+            elif file_type == 'tensorflow':
+                self.load_tensorflow(absolute_path, name)
 
     def load_json(self, path, name):
         with open(path) as json_file:
@@ -57,6 +59,11 @@ class ZIDS_SharedArtifacts():
         with open(path, 'rb') as pickle_file:
             setattr(self, name, pickle.load(pickle_file))
 
+    def load_tensorflow(self, path, name):
+        raise NotImplementedError
+        # with open(path) as json_file:
+        #     setattr(self, name, tf.keras.models.load_model(path))
+
     def get(self, key, default=None):
         if key in self.__dict__:
             return self.__dict__[key]
